@@ -4,11 +4,27 @@ our $AUTHORITY = 'cpan:GENE';
 use Moo;
 use POSIX qw( ceil );
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0104';
 
 use constant K => 3.14159265358979323846 / 180;
 
 
+sub _init_x {
+    my $self = shift;
+    return $self->width / 2;
+}
+
+sub _init_y {
+    my $self = shift;
+    return $self->height / 2;
+}
+
+sub _init_heading {
+    my $self = shift;
+    return -90 % 360;
+}
+
+
 has width => (
     is => 'rw',
     default => sub { 500 },
@@ -39,8 +55,6 @@ has pen_status => (
     is => 'rw',
     default => sub { 1 }, # Pen down
 );
-
-
 has pen_color => (
     is => 'rw',
     default => sub { 'black' },
@@ -50,21 +64,6 @@ has pen_size => (
     default => sub { 1 },
 );
 
-sub _init_x {
-    my $self = shift;
-    return $self->width / 2;
-}
-
-sub _init_y {
-    my $self = shift;
-    return $self->height / 2;
-}
-
-sub _init_heading {
-    my $self = shift;
-    return -90 % 360;
-}
-
 
 sub home {
     my $self = shift;
@@ -203,7 +202,7 @@ Data::Turtle
 
 =head1 VERSION
 
-version 0.0103
+version 0.0104
 
 =head1 SYNOPSIS
 
@@ -212,15 +211,15 @@ version 0.0103
   $turtle->pen_up;
   $turtle->turn(45);
   $turtle->forward(10);
-  $turtle->goto( 100, 100 );
+  $turtle->goto(100, 100);
   $turtle->mirror;
   $turtle->backward(10);
   $turtle->pen_down;
-  my ( $x, $y, $heading, $pen_status, $pen_color, $pen_size ) = $turtle->get_state;
-  $turtle->set_state( $x, $y, $heading, $pen_status, $pen_color, $pen_size );
-  for my $i ( 1 .. 4 ) {
+  my ($x, $y, $heading, $status, $color, $size) = $turtle->get_state;
+  $turtle->set_state($x, $y, $heading, $status, $color, $size);
+  for my $i (1 .. 4) {
       my @line = $turtle->forward(50);
-      # If there is a line, draw it...
+      # If there is a line and the pen is down, draw it!
       $turtle->right(90);
   }
 
@@ -239,69 +238,102 @@ L<Imager>.
 
 Turtle - Turtle Movement and State Operations
 
-=head1 ATTRIBUTES
-
-=head2 width, height
-
-Drawing surface dimensions.
-
-=head2 x, y, heading
-
-Coordinate parameters.
-
-=head2 pen_status
-
-Is the pen is up or down?
-
-=head2 pen_color, pen_size
-
-Pen properties.
-
 =head1 METHODS
 
-=head2 home()
+=head2 new
+
+  Data::Turtle->new();
+  Data::Turtle->new(
+    width      => $width,
+    height     => $height,
+    x          => $x0,
+    y          => $y0,
+    heading    => $heading,
+    pen_status => $pen_status,
+    pen_color  => $pen_color,
+    pen_size   => $pen_size,
+  );
+
+Return a C<Data::Turtle> object.
+
+Attributes:
+
+=over 4
+
+=item * width, height
+
+Drawing surface dimensions.  Defaults:
+
+  width  = 500
+  height = 500
+
+=back
+
+=over 4
+
+=item * x, y, heading
+
+Coordinate parameters.  Defaults:
+
+  x       = width / 2
+  y       = height / 2
+  heading = 0 (degrees)
+
+=back
+
+=over 4
+
+=item * pen_status, pen_color, pen_size
+
+Is the pen is up or down?  Default: 1 (down position)
+
+Pen properties.  Defaults: pen_color = the string 'black', pen_size = 1 (pixel)
+
+=back
+
+=head2 home
 
   $turtle->home;
 
 Move the turtle cursor to the starting x,y position and heading.
 
-=head2 pen_up()
+=head2 pen_up
 
   $turtle->pen_up;
 
 Raise the pen head to stop drawing.
 
-=head2 pen_down()
+=head2 pen_down
 
   $turtle->pen_down;
 
 Lower the pen head to begin drawing.
 
-=head2 turn()
+=head2 turn
 
   $turtle->right($degrees);
 
 Set the heading to the given degrees.
 
-=head2 right()
+=head2 right
 
   $turtle->right($degrees);
 
 Turn to the right.
 
-=head2 left()
+=head2 left
 
   $turtle->left($degrees);
 
 Turn to the left.
 
-=head2 position()
+=head2 position
 
   @pos = $turtle->position;
 
 Return the current pen position as a list of the x and y values.
 
-=head2 get_state()
+=head2 get_state
 
   @state = $turtle->get_state;
 
@@ -309,31 +341,31 @@ Return the following settings as a list:
 
  x, y, heading, pen_status, pen_color, pen_size
 
-=head2 set_state()
+=head2 set_state
 
   $turtle->set_state( $x, $y, $heading, $pen_status, $pen_color, $pen_size );
 
 Set the turtle state with the given parameters.
 
-=head2 forward()
+=head2 forward
 
   @line = $turtle->forward($steps);
 
 Move forward the given number of steps.
 
-=head2 backward()
+=head2 backward
 
   @line = $turtle->backward($steps);
 
 Move backward the given number of steps.
 
-=head2 mirror()
+=head2 mirror
 
   $turtle->mirror;
 
 Reflect the heading by multiplying by -1.
 
-=head2 goto()
+=head2 goto
 
   @line = $turtle->goto( $x, $y );
 
